---
title: Linux
date: 2024-04-03
---

So what's this Linux thing all about? What does Linux look like? What software
runs on Linux?

## What is Linux about?

You can find a good introduction to Linux
[here](https://www.geeksforgeeks.org/introduction-to-linux-operating-system/).

## What does Linux look like?

Over the last few years, Linux graphic user interfaces (GUI) have greatly
improved. Click to view screenshots of the current desktop environments  offered
by the Gnome and KDE Project.

- [GNOME Overview](https://release.gnome.org/46/)
- [KDE Overview](https://kde.org/announcements/megarelease/6/)

## How about software?

There is a very large selection of software for Linux. You can
[look here](https://wiki.archlinux.org/title/List_of_applications) for a start.

According to the now-defunct freshmeat.net (a large index of software
for Linux  and other Unices), there are over 23,000 projects in development.
Many of these programs are Open Source and/or free.

## Is it hard to make the switch?

One of the biggest concerns for prospective Linux users is whether they will
be able to use the same programs they did on Windows/macOS. People might have
to use particular software for their jobs, after all. Thankfully, this isn't
such a big problem anymore.

Nowadays, more and more software ships with native Linux support, including
[most](https://code.visualstudio.com/) [code](https://www.jetbrains.com/ides/)
[IDEs](https://eclipseide.org/), and even some multimedia programs like
[DaVinci Resolve](https://www.blackmagicdesign.com/products/davinciresolve) and
[Synthesizer V](https://dreamtonics.com/synthesizerv/).
Even if this isn't the case for you, you still have options. Plenty of free
alternatives to popular proprietary software exist (e.g.
[GIMP](https://www.gimp.org/) instead of Photoshop for image editing,
[Krita](https://krita.org/en/) instead of PaintTool SAI
for drawing, or [LibreOffice](https://www.libreoffice.org/) instead of
Microsoft Office). These programs are often compatible with the same file
formats, too. Still, if you absolutely must use the same program that you ran
on your Windows system, [Wine](https://www.winehq.org/) can be used to run
.EXEs. [Proton](https://www.protondb.com/) works on top of Wine so you can even
play many of the same PC games.

Currently, Linux only holds about 4% market share amongst desktop PCs, but as
the open source software ecosystem continues to evolve, and users get fed up
with Microsoft and Apple's business practices, this number is sure to climb.

## Getting Linux

Interested in trying out Linux? Our Getting started page will step you though
the  process of finding, installing, and tweaking Linux on your computer.

Installing Linux can sometimes be difficult, but the LUG is here to help!

1. back up all your data (see page on backups)
2. pick a distribution
3. decide if you want to dual boot with Windows/Mac or just overwrite everything
4. install it:
   - come to quarterly installfest
   - stop by the lounge any time and somebody might help
   - do it yourself!

## Distros

Choosing a distribution can be challenging! (Though it actually matters less
than you think.)

Here's a short and incomplete list to help you choose:

### Debian-based
1. Debian
2. Ubuntu
3. Linux Mint
4. MX Linux
5. Pop! OS
6. Elementary OS
7. Zorin OS
8. Kali (for hackers)

### Arch-based
1. EndeavourOS
2. Manjaro
3. Garuda
4. Arch (hard)
5. Artix

## RedHat-based
1. Fedora
2. Red Hat (usually used on servers, including the UCLA lnxsrvs)
3. CentOS (Red Hat but without the tech support)
4. OpenSUSE

## Minimalist operating systems
For advanced users:
1. Void Linux
2. Gentoo
3. OpenBSD
4. FreeBSD
5. Slackware

## Tips for selecting a distro
If you are a beginner and you don't want to mess with the terminal that  much,
choose a Debian based one like Mint. Most of the Debian ones just  work straight
out of the box. There's also tons of support.

If you have some experience (or you're a beginner who is fine  with using the
terminal), you can try one of the Arch-based  distributions. Installing Arch
takes a while, but it's actually not too  hard. If you're too lazy to install
Arch, choose a distribution with a  graphical installer (like EndeavourOS).

Here's a quiz you can try: https://distrochooser.de/en/

## Comparing Arch and Debian

Choose Arch-based distributions if you want a minimal distribution. Choose
Debian based distributions if you want stability or ease of use.

# Desktop Environment

The **desktop environment** (DE) is what makes up most of the user interface. It
may include system panels, docks, window borders, backgrounds, and desktop
widgets, among  other things. GNU/Linux has a wide variety of DEs avaliable—this
page  will outline some of the most popular ones.

It is important to note that no DE is tied to a particular  GNU/Linux
distribution, or vice versa. Thus, if your distribution of  choice is Debian,
you may use GNOME, or KDE, or both GNOME and KDE (if  you installed both). You
can install as many different DEs as you want  and try them all!

The three main desktop environments are XFCE, KDE, and GNOME.

* **XFCE:** XFCE is designed to be fast and minimalist
* **GNOME:** GNOME is simpler to use, and looks nicer. Of course, this comes  at the cost of performance (the difference isn't that much though).
* **KDE:** KDE is in between GNOME and XFCE in terms of performance and features. If you are unsure, KDE is a good choice.

### Tiling windows managers:

Tiling window managers are a lot more difficult to use, and aren't for
beginners. Navigation is usually done using the keyboard as opposed to  the
mouse.

## FOSS Software

Below is an overview of some popular software for Linux. For more software and
downloads, check out our Software Downloads section.

### Web Browser - Firefox, Chromium

Firefox is a standards-compliant open source web browser developed by the free
software community with the cooperation and support of Mozilla  Corporation.
Firefox provides all essential features of a browser for  the modern web, and
also a wide variety of add-ons that will undoubtedly satisfy anybody's needs and
wants.

Chromium is the open source web browser project from which Google Chrome draws
its source code.

### Office Suite - LibreOffice

LibreOffice is a free and open source office suite. It includes key office
applications such as a word processor, spreadsheet, presentation  manager, and
drawing program, all with a user interface and feature set  similar to other
office suites.

Sophisticated and flexible, LibreOffice also works transparently  with a variety
of file formats, including those of Microsoft Office. It  primarily supports the
Open Document Formats (ODF), such as .odt  (documents), .ods (spreadsheets), and
.odp (presentations). Here at the  LUG, these are the formats we primarily use.
Also, many European  governments are adopting ODF as the official format for
electronic  documents. ODF and LibreOffice promotes total interoperability and
information integrity.

### Instant Messaging - Pidgin, Empathy

Pidgin is a messaging program that supports multiple protocols, including
XMPP/Jabber (e.g. Google Talk), IRC, MSN, AIM, ICQ, amd Yahoo!. It  features
many plugins and has a large community surrounding it.

Empathy is a messaging program that supports XMPP/Jabber (e.g.  Google Talk),
SIP, IRC, MSN, AIM, ICQ, and Yahoo!. It supports voice and video calls (only for
XMPP and SIP), and has excellent integration with the GNOME desktop.

### Audio Player - VLC, MPlayer, Clementine

VLC is famously known as the player that "plays everything." It can handle
DVDs, (S)VCDs, Audio CDs, web streams, TV cards and much more. You don't need to
keep track of a dozen codec packs you need to have installed.  VLC has nearly
all codecs built-in. It can even play the file or media  if it is damaged!

- Comparison of audio player software - Wikipedia

### Movie Player - MPlayer, VLC

MPlayer is a movie player for Linux. It plays most MPEG, VOB, AVI, VIVO,
ASF/WMV, QT/MOV, FLI, NuppelVideo, yuv4mpeg, FILM, RoQ, and OGG files,  and some
files for RealMedia. You can watch VideoCD, SVCD, DVD, 3ivx,  FLI, and even DivX
movies too.

Another big feature of MPlayer is the wide range of supported  output drivers.
MPlayer supports displaying through a number of hardware MPEG decoder boards
such as the DVB and DXR3/Hollywood+ . And what  about nice, big anti-aliased
shaded subtitles (9 supported types!!!)  with european/ISO 8859-1,2 (hungarian,
english, czech, etc), cyrillic,  korean fonts, and OSD.

### Graphics Software - GIMP, Inkscape

GIMP is a professional *raster* image manipulation program, and part of the GNU
project. It is suitable for tasks such as photo retouching, image composition,
image authoring, or any other task that requires manipulation of raster images.

Inkscape is a professional *vector* image manipulation/creation program.

### Programming - Gcc, Eclipse, Qt

The GNU Compiler Collection contains frontends for C, C++, Objective C,  Chill,
Fortran, and Java, as well as libraries for these languages. It  is a
full-featured ANSI C compiler, with support for K&R C as well.

GCC provides many levels of source code error checking  traditionally provided
by other tools (such as lint), produces debugging information, and can perform
many different optimizations to the  resulting object code.

### Games
A quick list of popular games that have been ported to Linux:
- Civilization: Call to Power
- Counter Strike
- Counter Strike: Source
- Descent 3
- Doom 1/2/3
- Half Life
- Half Life: Source
- Half Life 2 , HL2: E1, HL2: E2
- Homeworld
- Kerbal Space Program
- Never Winter Nights
- Postal 2
- Quake 1/2/3 (see ioquake3-based projects, such as OpenArena)
- Sid Meier's Alpha Centauri
- Simcity 3000 Unlimited
- Soldier Of Fortune
- Team Fortress 2
- Tribes 2
- Unreal Tournament

Here are some fun open source games:
- SuperTux
- SuperTuxKart
- Xonotic
